public extension MicItem {
  /// Следует задать активность элемента
  ///
  /// Условия:
  /// 1. Пришла актуальная дата завершения активности
  /// 2. Таймер сообщил о завершении активности
  ///
  /// - Returns: Состояние активности элемента
  static func shouldResetActivity(_ c: MicItemContext) -> Bool? {
    if
      c.activityDate.isRecent,
      let end = c.activityDate.value
    {
      let now = Date()
      return now < end
    }

    if c.timeout {
      return false
    }

    return nil
  }

  /// Следует задать время истечения активности
  ///
  /// Условия:
  /// 1. Пришла актуальная дата завершения активности
  ///
  /// - Returns: Время истечения активности
  static func shouldResetTimeout(_ c: MicItemContext) -> TimeInterval? {
    if
      c.activityDate.isRecent,
      let end = c.activityDate.value
    {
      let timeout = end.timeIntervalSinceNow
      return timeout > 0 ? timeout : nil
    }

    return nil
  }
}
